uNoGS api endpoint url.
Can be rebound for a set of calls using the with-api-url macro.
uNoGS api endpoint url. Can be rebound for a set of calls using the `with-api-url` macro.
Default headers map sent with all api requests.
Can be rebound for a set of calls using the with-headers macro.
set-api-key can be used to add your api key to the headers.
Default headers map sent with all api requests. Can be rebound for a set of calls using the `with-headers` macro. `set-api-key` can be used to add your api key to the headers.
(advanced-search &
{:keys [query clist genreid vtype audio subtitle
audio-sub-andor simdbrate eimdbrate imdbvotes
votes-gt-lt snfrate enfrate syear eyear downloadable
sortby page api-key]
:or {audio "Any"
query ""
audio-sub-andor "and"
clist "all"
imdbvotes 0
syear 1900
eimdbrate 10
downloadable nil
simdbrate 0
enfrate 5
page 1
snfrate 0
sortby "Relevance"
eyear 3000
subtitle "Any"
vtype "Any"
genreid 0
votes-gt-lt "gt"}})Query the api for results that match an advanced search filter. The following parameters are accepted:
:query - An optional map that specifies the type of search. If not
provided the query will return all items that match the other supplied
parameters. Each map must contain a :type key with one of the following
values:
:title - Contains :title that specifies a title string to search for.{:type :title, :title "Bird Box"}:new-releases - Contains :daysback.{:type :new-releases, :daysback 7}:season-changes - Contains :daysback.{:type :season-changes, :daysback 10}:expiring - Contains :countryid.{:type :expiring, :countryid "US"}:clist - A single numerical country id, a vector of then, or "all". Note
that two letter country codes (ex. US) are not valid here. For a list of
corresponding numerical and letter ids call list-countries.
:genreid - A numerical genre id. Call genre-ids for a list.
:vtype - "Any", "Movie" or "Series".
:audio - An audio langugage. Ex. "English" or "Chinese".
:subtitle - A subtitle language. Ex. "English" or "Chinese".
:audio-sub-andor - "and" or "or". Determines whether an item must have
both the audio and subtitle languages match, or either of them match.
:simdbrate - Minimum imdb rating. An integer in the range of 0 to 10.
:eimdbrate - Maximum imdb rating. An integer in the range of 0 to 10.
:imdbvotes - A number of votes for an item to have recieved on IMDB. Can
either be tested against as a floor or ceiling based on the value of
:votes-gt-lt.
:votes-gt-lt - "gt" or "lt". Determines whether the value of
:imdbvotes is tested as a floor or ceiling.
:snfrate - Minimum netflix rating. An integer in the range of 0 to 5.
:enfrate - Maximum netflix rating. An integer in the range of 0 to 5.
:syear - The minimum release year.
:eyear - The maximum release year.
:downloadable - An optional value. "Yes", "No" or unspecified.
:sortby - Sort results by "Relevence", "Date", "Rating", "Title",
"VideoType", "FilmYear", or "Runtime".
:page - An integer 1 or greater. Groups of up to 100 results will be
returned and this value will page through them.
As almost all of the above parameters are required, so the most inclusive values are used by default.
An :api-key can be passed to this function, overwriting the api key
specified globally via the set-api-key function.
uNoGS documentation: https://rapidapi.com/unogs/api/unogs?endpoint=5690bcdee4b0e203818a6518
Query the api for results that match an advanced search filter.
The following parameters are accepted:
* `:query` - An optional map that specifies the type of search. If not
provided the query will return all items that match the other supplied
parameters. Each map must contain a `:type` key with one of the following
values:
1. `:title` - Contains `:title` that specifies a title string to search for.
* Ex. `{:type :title, :title "Bird Box"}`
2. `:new-releases` - Contains `:daysback`.
* Ex. `{:type :new-releases, :daysback 7}`
3. `:season-changes` - Contains `:daysback`.
* Ex. `{:type :season-changes, :daysback 10}`
4. `:expiring` - Contains `:countryid`.
* Ex. `{:type :expiring, :countryid "US"}`
* `:clist` - A single numerical country id, a vector of then, or "all". Note
that two letter country codes (ex. US) are not valid here. For a list of
corresponding numerical and letter ids call `list-countries`.
* `:genreid` - A numerical genre id. Call `genre-ids` for a list.
* `:vtype` - "Any", "Movie" or "Series".
* `:audio` - An audio langugage. Ex. "English" or "Chinese".
* `:subtitle` - A subtitle language. Ex. "English" or "Chinese".
* `:audio-sub-andor` - "and" or "or". Determines whether an item must have
both the audio and subtitle languages match, or either of them match.
* `:simdbrate` - Minimum imdb rating. An integer in the range of 0 to 10.
* `:eimdbrate` - Maximum imdb rating. An integer in the range of 0 to 10.
* `:imdbvotes` - A number of votes for an item to have recieved on IMDB. Can
either be tested against as a floor or ceiling based on the value of
`:votes-gt-lt`.
* `:votes-gt-lt` - "gt" or "lt". Determines whether the value of
`:imdbvotes` is tested as a floor or ceiling.
* `:snfrate` - Minimum netflix rating. An integer in the range of 0 to 5.
* `:enfrate` - Maximum netflix rating. An integer in the range of 0 to 5.
* `:syear` - The minimum release year.
* `:eyear` - The maximum release year.
* `:downloadable` - An optional value. "Yes", "No" or unspecified.
* `:sortby` - Sort results by "Relevence", "Date", "Rating", "Title",
"VideoType", "FilmYear", or "Runtime".
* `:page` - An integer 1 or greater. Groups of up to 100 results will be
returned and this value will page through them.
As almost all of the above parameters are required, so the most inclusive values
are used by default.
An `:api-key` can be passed to this function, overwriting the api key
specified globally via the set-api-key function.
uNoGS documentation: https://rapidapi.com/unogs/api/unogs?endpoint=5690bcdee4b0e203818a6518(all-pages f)Take an api call f and call it for each page to aggregate all items.
This macro does not take into account the possibility of a change in the number of items in between api calls effecting the number of pages required to fetch all items.
Take an api call `f` and call it for each page to aggregate all items. This macro does not take into account the possibility of a change in the number of items in between api calls effecting the number of pages required to fetch all items.
(api-call method
&
{:keys [query-params api-key headers url]
:or {headers *headers* url *api-url*}})Perform the specified method call to the api.
If this function is not provided values for :headers or :url will use the
default global values *headers* and *api-url* respectively.
Perform the specified `method` call to the api. If this function is not provided values for `:headers` or `:url` will use the default global values `*headers*` and `*api-url*` respectively.
(deleted daysback & {:keys [countryid title api-key]})Query the api for items deleted during daysback.
Optionally, search for a specific :title and/or in a specific
:countryid.
This request has a special case, where its :countryid can either be the
standard, two letter country ID, or it can be a collection of numerical
country codes found by calling list-countries.
This query returns every item that matches the criteria, so there is no need
to supply a :page value.
An :api-key can be passed to this function, overwriting the api key
specified globally via the set-api-key function.
uNoGS documentation: https://rapidapi.com/unogs/api/unogs?endpoint=5c23d6cee4b067d7d9563e18
Query the api for items deleted during `daysback`. Optionally, search for a specific `:title` and/or in a specific `:countryid`. This request has a special case, where its `:countryid` can either be the standard, two letter country ID, or it can be a collection of numerical country codes found by calling `list-countries`. This query returns every item that matches the criteria, so there is no need to supply a `:page` value. An `:api-key` can be passed to this function, overwriting the api key specified globally via the set-api-key function. uNoGS documentation: https://rapidapi.com/unogs/api/unogs?endpoint=5c23d6cee4b067d7d9563e18
(episode-details netflixid & {:keys [api-key]})Query the api for episode details of netflixid.
An :api-key can be passed to this function, overwriting the api key
specified globally via the set-api-key function.
uNoGS documentation: https://rapidapi.com/unogs/api/unogs?endpoint=56770f5ae4b059e645dc3d57
Query the api for episode details of `netflixid`. An `:api-key` can be passed to this function, overwriting the api key specified globally via the set-api-key function. uNoGS documentation: https://rapidapi.com/unogs/api/unogs?endpoint=56770f5ae4b059e645dc3d57
(expiring countryid & {:keys [page api-key] :or {page 1}})Query the api for items expiring in countryid.
Up to 100 results will be returned. Additional items can be accessed by
providing :page greater than 1.
An :api-key can be passed to this function, overwriting the api key
specified globally via the set-api-key function.
uNoGS documentaion: https://rapidapi.com/unogs/api/unogs?endpoint=56757595e4b04bcce8ec15ad
Query the api for items expiring in `countryid`. Up to 100 results will be returned. Additional items can be accessed by providing `:page` greater than 1. An `:api-key` can be passed to this function, overwriting the api key specified globally via the set-api-key function. uNoGS documentaion: https://rapidapi.com/unogs/api/unogs?endpoint=56757595e4b04bcce8ec15ad
(genre-ids & {:keys [api-key]})Query the api for a map of genres and corresponding ids.
The output of this function is slightly transformed from the response format. The generes are given as a vector where each element is a map containing a single pairing of a genre key to a vector of its genre ids. For your convenience, this is flattened into a single map of genre keys to their genre ids.
An :api-key can be passed to this function, overwriting the api key
specified globally via the set-api-key function.
uNoGS documentation: https://rapidapi.com/unogs/api/unogs?endpoint=5676f219e4b04efee9356e43
Query the api for a map of genres and corresponding ids. The output of this function is slightly transformed from the response format. The generes are given as a vector where each element is a map containing a single pairing of a genre key to a vector of its genre ids. For your convenience, this is flattened into a single map of genre keys to their genre ids. An `:api-key` can be passed to this function, overwriting the api key specified globally via the set-api-key function. uNoGS documentation: https://rapidapi.com/unogs/api/unogs?endpoint=5676f219e4b04efee9356e43
(images netflixid & {:keys [api-key]})Query the api for images corresponding to netflixid.
An :api-key can be passed to this function, overwriting the api key
specified globally via the set-api-key function.
uNoGS documentation: https://rapidapi.com/unogs/api/unogs?endpoint=57304268e4b002251bb1798d
Query the api for images corresponding to `netflixid`. An `:api-key` can be passed to this function, overwriting the api key specified globally via the set-api-key function. uNoGS documentation: https://rapidapi.com/unogs/api/unogs?endpoint=57304268e4b002251bb1798d
(imdb-info filmid & {:keys [api-key]})Query the api for imdb info of filmid (a netflix or imdb id).
An :api-key can be passed to this function, overwriting the api key
specified globally via the set-api-key function.
uNoGS documentation: https://rapidapi.com/unogs/api/unogs?endpoint=5ab02664e4b06ec3937b50a2
Query the api for imdb info of `filmid` (a netflix or imdb id). An `:api-key` can be passed to this function, overwriting the api key specified globally via the set-api-key function. uNoGS documentation: https://rapidapi.com/unogs/api/unogs?endpoint=5ab02664e4b06ec3937b50a2
(imdb-update imdbid & {:keys [api-key]})Query the api to update the imdb info of imdbid.
An :api-key can be passed to this function, overwriting the api key
specified globally via the set-api-key function.
uNoGS documentation: https://rapidapi.com/unogs/api/unogs?endpoint=58179d9ee4b0c681e4af7b08
Query the api to update the imdb info of `imdbid`. An `:api-key` can be passed to this function, overwriting the api key specified globally via the set-api-key function. uNoGS documentation: https://rapidapi.com/unogs/api/unogs?endpoint=58179d9ee4b0c681e4af7b08
(list-countries & {:keys [available api-key] :or {available true}})Query the api for a list of countries.
By default, it will return a list of countries where uNoGS information is
actively updated. By providing :available false, it will return a list of
countries where uNoGS is actively updated and countries that were previously
cataloged.
An :api-key can be passed to this function, overwriting the api key
specified globally via the set-api-key function.
uNogs documentation: https://rapidapi.com/unogs/api/unogs?endpoint=56770144e4b0c2a9f0e83c8e
Query the api for a list of countries. By default, it will return a list of countries where uNoGS information is actively updated. By providing `:available false`, it will return a list of countries where uNoGS is actively updated and countries that were previously cataloged. An `:api-key` can be passed to this function, overwriting the api key specified globally via the set-api-key function. uNogs documentation: https://rapidapi.com/unogs/api/unogs?endpoint=56770144e4b0c2a9f0e83c8e
(new-releases daysback countryid & {:keys [page api-key] :or {page 1}})Query the api for new releases during daysback in countryid.
Up to 100 results will be returned. Additional items can be accessed by
providing :page greater than 1.
An :api-key can be passed to this function, overwriting the api key
specified globally via the set-api-key function.
uNoGS documentation: https://rapidapi.com/unogs/api/unogs?endpoint=5675480ee4b059e645dc3a63
Query the api for new releases during `daysback` in `countryid`. Up to 100 results will be returned. Additional items can be accessed by providing `:page` greater than 1. An `:api-key` can be passed to this function, overwriting the api key specified globally via the set-api-key function. uNoGS documentation: https://rapidapi.com/unogs/api/unogs?endpoint=5675480ee4b059e645dc3a63
(season-changes daysback countryid & {:keys [page api-key] :or {page 1}})Query the api for changes to TV series seasons during daysback in countryid.
Up to 100 results will be returned. Additional items can be accessed by
providing :page greater than 1.
An :api-key can be passed to this function, overwriting the api key
specified globally via the set-api-key function.
uNoGS documentation: https://rapidapi.com/unogs/api/unogs?endpoint=56c4b2c5e4b07732012a3315
Query the api for changes to TV series seasons during `daysback` in `countryid`. Up to 100 results will be returned. Additional items can be accessed by providing `:page` greater than 1. An `:api-key` can be passed to this function, overwriting the api key specified globally via the set-api-key function. uNoGS documentation: https://rapidapi.com/unogs/api/unogs?endpoint=56c4b2c5e4b07732012a3315
(set-api-key api-key)(title-details netflixid & {:keys [api-key]})Query the api for title details of netflixid.
An :api-key can be passed to this function, overwriting the api key
specified globally via the set-api-key function.
uNoGS documentation: https://rapidapi.com/unogs/api/unogs?endpoint=56770d2de4b04efee9356e62
Query the api for title details of `netflixid`. An `:api-key` can be passed to this function, overwriting the api key specified globally via the set-api-key function. uNoGS documentation: https://rapidapi.com/unogs/api/unogs?endpoint=56770d2de4b04efee9356e62
(weekly-episodes & {:keys [api-key]})Query the api for a list of netflix title id's with weekly added episodes.
An :api-key can be passed to this function, overwriting the api key
specified globally via the set-api-key function.
uNoGS documentation: https://rapidapi.com/unogs/api/unogs?endpoint=570212a0e4b028dd93816233
Query the api for a list of netflix title id's with weekly added episodes. An `:api-key` can be passed to this function, overwriting the api key specified globally via the set-api-key function. uNoGS documentation: https://rapidapi.com/unogs/api/unogs?endpoint=570212a0e4b028dd93816233
(weekly-updates daysback & {:keys [title countryid api-key]})Query the api for for a list of titles with series that update weekly within
daysback.
Optionally, a specific title or country can be searched by supplying :title
or :countryid respectively.
This request contains a special case, where :countryid can either be the
standard, two letter country ID, or it can be given as a collection of them.
An :api-key can be passed to this function, overwriting the api key
specified globally via the set-api-key function.
uNoGS documentation: https://rapidapi.com/unogs/api/unogs?endpoint=5c617d57e4b08cf00f3fd3ea
Query the api for for a list of titles with series that update weekly within `daysback`. Optionally, a specific title or country can be searched by supplying `:title` or `:countryid` respectively. This request contains a special case, where `:countryid` can either be the standard, two letter country ID, or it can be given as a collection of them. An `:api-key` can be passed to this function, overwriting the api key specified globally via the set-api-key function. uNoGS documentation: https://rapidapi.com/unogs/api/unogs?endpoint=5c617d57e4b08cf00f3fd3ea
(with-api-url new-api-url & body)Rebind *api-url* with new-api-url in body.
Rebind `*api-url*` with `new-api-url` in `body`.
(with-headers new-headers & body)Rebind *headers* with new-headers in body.
Rebind `*headers*` with `new-headers` in `body`.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |